==> ejc-jltest-api-3.0.0-20240321.001859-91-sources.jar: com/ejianc/business/jltest/margin/vo/EmployeeDetailsVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 员工明细表 b做的
 * 
 * @author generator
 * 
 */
public class EmployeeDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 员工明细表编码
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private String isStages; // 是否分期
    private BigDecimal payableAmount; // 应缴纳金额
    private BigDecimal actualPaidAmount; // 实际已缴纳金额
    private String actualPaidProportion; // 实际已缴纳比例
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getIsStages() {
        return isStages;
    }

    public void setIsStages(String isStages) {
        this.isStages = isStages;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getActualPaidAmount() {
        return actualPaidAmount;
    }

    public void setActualPaidAmount(BigDecimal actualPaidAmount) {
        this.actualPaidAmount = actualPaidAmount;
    }
    public String getActualPaidProportion() {
        return actualPaidProportion;
    }

    public void setActualPaidProportion(String actualPaidProportion) {
        this.actualPaidProportion = actualPaidProportion;
    }
    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    
}

==> ejc-jltest-api-3.0.0-20240328.002507-125-sources.jar: com/ejianc/business/jltest/margin/vo/EmployeeDetailsVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 员工明细表 b做的
 * 
 * @author generator
 * 
 */
public class EmployeeDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 员工明细表编码
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private String isStages; // 是否分期
    private BigDecimal payableAmount; // 应缴纳金额
    private BigDecimal actualPaidAmount; // 实际已缴纳金额
    private String actualPaidProportion; // 实际已缴纳比例
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额
    private Integer billState; //单据状态

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getIsStages() {
        return isStages;
    }

    public void setIsStages(String isStages) {
        this.isStages = isStages;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getActualPaidAmount() {
        return actualPaidAmount;
    }

    public void setActualPaidAmount(BigDecimal actualPaidAmount) {
        this.actualPaidAmount = actualPaidAmount;
    }
    public String getActualPaidProportion() {
        return actualPaidProportion;
    }

    public void setActualPaidProportion(String actualPaidProportion) {
        this.actualPaidProportion = actualPaidProportion;
    }
    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    
}
